//---------------------------------------------------
// VS[h
//---------------------------------------------------

#include "VSMode.h"

CVSMode::CVSMode()
{
}

CVSMode::~CVSMode()
{
	field.deleteField();
	nageru_p1.deleteModel(DB);
	nageru_p2.deleteModel(DB);
	interFace.deleteImage(DB);
	sound.deleteSound(DB);
}

void CVSMode::init()
{
	camera.setAddress(DB->systemDB.getCamera());

	loadBG();

	interFace.setGraph(DB);
	interFace.removeRocking_P2_Icon(DB);
	interFace.setHelp(DB,false);
	
	timer.initTime();
	nageru_p1.loadModel(DB, "nageru_p1", "ino_p1", "ino_throw_p1", "return_p1");
	nageru_p1.init(DB);
	nageru_p1.setMaxLife( maxLife );

	
	nageru_p2.loadModel(DB, "nageru_p2", "ino_p2", "ino_throw_p2", "return_p2");
	nageru_p2.init(DB);
	nageru_p2.setMaxLife( maxLife );


	field.setAddress( DB->systemDB.getScene() );

	field.loadEditFieldData( DB->systemDB.getStageNum() , &nageruPos , &enemyPos );
	nageru_p1.setPos(nageruPos );
	nageru_p2.setPos(enemyPos);


	effect_p1.init(DB);
	effect_p2.init(DB);


	sound.init(DB);
	//sound.playMainBGM(DB);
	sound.playBattleBGM(DB);

	for(int i=0; i<10; i++ )
	{
		repairID[i] = -1;
	}

	standBlockID = 9999;

	DB->graphDB.setImage("continue", "dat/graph/maingame/continue.png");
	DB->graphDB.removeImage("continue");
	DB->graphDB.setImage("yes", "dat/graph/maingame/yes.png");
	DB->graphDB.removeImage("yes");
	DB->graphDB.setImage("no", "dat/graph/maingame/no.png");
	DB->graphDB.removeImage("no");
	DB->graphDB.setImage("cursor", "dat/graph/interface/cursor.png");
	DB->graphDB.removeImage("cursor");

	DB->effectDB.createEffect("cursor_p1", "dat/graph/maingame/cursor_p1_test.png", 1, 1);
	DB->effectDB.setSize("cursor_p1", 30, 30);
	DB->effectDB.setRendMode("cursor_p1");
	DB->effectDB.entryEffect("cursor_p1");
	DB->effectDB.createEffect("cursor_p2", "dat/graph/maingame/cursor_p2_test.png", 1, 1);
	DB->effectDB.setSize("cursor_p2", 30, 30);
	DB->effectDB.setRendMode("cursor_p2");
	DB->effectDB.entryEffect("cursor_p2");

	cursorNum = 0;

	zeroSpd = fk_Vector(0.0, 0.0, 0.0);
}

bool CVSMode::onPeriod()
{
	field.setShadow( true , nageru_p1.getPos() , 10.0 );
	field.setShadow( false , nageru_p2.getPos() , 10.0 );

	if(nageru_p2.getMotionStatus() != 12 && nageru_p2.getMotionStatus() != 13 &&
		nageru_p1.getMotionStatus() != 12 && nageru_p1.getMotionStatus() != 13)
	{
		timer.addTime(0.0166666667);
	}

	/*
	//P1
	*/
	nageru_p1.motionStateStand();

	nageru_p1.setView(DB->systemDB.getCamera()->getVec() );
	nageru_p1.initSpd();

	if( input->checkPress( INPUT_UP  ) )
	{
		nageru_p1.moveAction(DIRECTION_UP);
	}
	if( input->checkPress( INPUT_DOWN ) )
	{
		nageru_p1.moveAction(DIRECTION_DOWN);
	}
	if( input->checkPress( INPUT_LEFT  ) )
	{
		nageru_p1.moveAction(DIRECTION_LEFT);
	}
	if( input->checkPress( INPUT_RIGHT ) )
	{
		nageru_p1.moveAction(DIRECTION_RIGHT);
	}
	nageru_p1.normSpd();
	//{^
	//XbV
	if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
	{
		throwBlockID = nageru_p1.doAttack(DB->systemDB.getScene());
		if(throwBlockID != 9999 )
		{
			field.blockLost(throwBlockID, 1 );
		}
	}
	//X[
	if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
	{
		throwBlockID = nageru_p1.doThrow(DB->systemDB.getScene());
		if(throwBlockID != 9999 )
		{
			nageru_p1.startCalcThrowBlockDistance(throwBlockID);
			nageru_p1.entryVSThrowBlock(throwBlockID % 1000);

			blockSpd = nageru_p2.getPos() - nageru_p1.getPos();
			blockSpd.normalize();
			field.blockThrow( throwBlockID, nageru_p1.getPos() ,blockSpd * 3 );
			nageru_p1.setThrowSpd(blockSpd);

			sound.playThrowSE(DB);
		}
	}
	//Wv
	if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
	{
		if(nageru_p1.getMovingBase().canJump == true )
		{
			nageru_p1.jumpAction(false);
			sound.playJumpSE(DB);
		}
	}
	//tg
	if( !input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_4, PAD2 ) )
	{
		if(standBlockID >= 1000 && standBlockID != 9999 && nageru_p2.getStatusBase().stock < 6 )
		{
			field.blockLift( standBlockID - 1000);
			nageru_p2.entryLiftBlock( DB->systemDB.getScene(), standBlockID - 1000 );
			nageru_p2.jumpAction(true);
			sound.playLiftSE(DB);
		}
	}
	if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
	{
		if(nageru_p1.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_RUSH;
			nageru_p1.summonAnima(DB, ino_motionStatus );
			sound.playSummonAnimaSE(DB);
		}
	}
	if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
	{
		if(nageru_p1.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_THROW;
			nageru_p1.summonAnima(DB, ino_motionStatus );
			nageru_p1.setThrowFocus(nageru_p2.getPos() );
			sound.playSummonAnimaSE(DB);
		}
	}
	if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
	{
		if(nageru_p1.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_CURE;
			nageru_p1.summonAnima(DB, ino_motionStatus );	
			effect_p1.heal.effectSet(DB, nageru_p1.getPModel());
			sound.playSummonAnimaSE(DB);
		}
	}
	//Aj}yA
	if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
	{
		if(nageru_p1.getStatusBase().anima >= 1.0 )
		{
			for(int i=0 ; i<10; i++ )
			{
				repairID[i] = -1;
			}
			field.blockRevival(1, repairID);
			for(int i=0 ; i<10; i++ )
			{
				if( repairID[i] > -1 )
				{
					effect_p1.repair.effectSet(DB, field.getModel(repairID[i] ));
				}
			}
			sound.playSummonAnimaSE(DB);

			ino_motionStatus = INO_REPAIR;
			nageru_p1.summonAnima(DB, ino_motionStatus );
		}
	}
	if(input->checkPress( INPUT_SELECT) && input->checkPress( INPUT_START)  )
		{
			DB->systemDB.fade( -100 );
			sound.stopMainBGM(DB);
			sound.stopRockingBGM(DB);
			sound.stopBontaBGM(DB);
			nageru_p1.removeIno(DB, true);
			nageru_p2.removeIno(DB, true);
			*scene = S_TITLE;
			return true;
		}
	
	nageru_p1.setGravity();
	nageru_p1.moveAttack();
	nageru_p1.addAcc();
	nageru_p1.dashAction();

	//P1F΃XbV@Փ˔
	if(nageru_p2.getAttackFlag() == true &&
		DB->modelDB.checkCollision("nageru_p1", nageru_p2.getAttackPObb(), &zeroSpd ) )
	{
		effect_p2.slash.effectSet(DB, nageru_p2.getPAttackModel() );

		nageru_p2.setAttackFlag(false );
		nageru_p2.addCombo();
		nageru_p1.setDamage(nageru_p2.getAttackDamage(), 5 );
		sound.playSlashSE(DB);
		nageru_p2.plusAnimaGauge(0.02);
	}
	//P1F΃X[@Փ˔
	hitThrowBlockID = field.checkCollision( DB->modelDB.getOBB("nageru_p1") , nageru_p2.getPThrowSpd(), 3 )  % 1000;
	if(hitThrowBlockID != 999 && nageru_p1.checkHitVSThrowBlockID(hitThrowBlockID) == true)
	{
		effect_p2.throwHit.effectSet(DB, field.getModel(hitThrowBlockID));
		nageru_p2.addCombo();
		nageru_p2.stopCalcThrowBlockDistance(hitThrowBlockID );
		nageru_p2.removeVSThrowBlockID(hitThrowBlockID);
		field.blockLost(hitThrowBlockID, 2);
		nageru_p1.setDamage(nageru_p2.getThrowDamage(), 0 );
		sound.playEnemyDamageSE(DB);
		nageru_p2.plusAnimaGauge(0.01);
	}
	//P1F΃Aj}bV@Փ˔
	if(nageru_p2.getAnimaRushFlag() == true &&
		DB->modelDB.checkCollision("nageru_p1", "ino_p2", &zeroSpd ) )
	{
		effect_p2.rush.effectSet(DB, nageru_p1.getPModel() );

		nageru_p2.addCombo();
		nageru_p2.setAnimaRushFlag(false);
		nageru_p1.setDamage(nageru_p2.getAnimaRushDamage(), 3 );
		sound.playEnemyDamageSE(DB);
	}
	//P1F΃Aj}X[@Փ˔
	if(nageru_p2.getAnimaThrowFlag() == true &&
		DB->modelDB.checkCollision("nageru_p1", "ino_throw_p2", nageru_p2.getPanimaThrowSpd() ) )
	{
		effect_p2.Animathrow.effectSet(DB, nageru_p2.getPAnimaThrowModel() );

		nageru_p2.addCombo();
		nageru_p2.removeAnimaThrow(DB);
		nageru_p1.setDamage(nageru_p2.getAnimaThrowDamage(), 0 );

		sound.playEnemyDamageSE(DB);
	}
	//P1FP2Փ˔
	DB->modelDB.checkCollision("nageru_p2", "nageru_p1", nageru_p1.getPSpd() );

	//P1FՓ˔
	standBlockID = field.checkCollision( DB->modelDB.getOBB("nageru_p1") , nageru_p1.getPSpd(), 1 );
	if(standBlockID != 9999  )
	{
		nageru_p1.initAcc();
		nageru_p1.motionStateStop();
		field.setStandBlock(standBlockID - 1000, 0);
	}

	if(nageru_p1.setFallState() == true)
	{
		nageru_p1.setDamage( 10, 240 );
		sound.playFallSE(DB);
	}
	nageru_p1.updateFly(DB);

	nageru_p1.translatePlayer(DB);

	nageru_p1.setVecEnemy( nageru_p2.getPos() );
	nageru_p1.motionStateFall();
	nageru_p1.updateDamageMotion();
	nageru_p1.updateDead(DB);
	nageru_p1.updateAnima(DB);
	nageru_p1.updateModel(DB);
	nageru_p1.moveLiftBlock();

	nageru_p1.removeIno(DB, false);


	nageru_p1.plusAnimaGauge(0.001);

	nageru_p1.updateAnimaThrow(DB);
	nageru_p1.updateAttack(DB);
	nageru_p1.updateCombo();
	nageru_p1.stopMotionStatus( DB);	//U[VĨ[V~
	nageru_p1.updateInv();
	field.removeStandBlock(0);


	/*
	//P2
	*/
	nageru_p2.motionStateStand();


	nageru_p2.setView(DB->systemDB.getCamera()->getVec() );
	nageru_p2.initSpd();

	if( input->checkPress( INPUT_UP, PAD2  ) )
	{
		nageru_p2.moveAction(DIRECTION_UP);
	}
	if( input->checkPress( INPUT_DOWN, PAD2 ) )
	{
		nageru_p2.moveAction(DIRECTION_DOWN);
	}
	if( input->checkPress( INPUT_LEFT, PAD2  ) )
	{
		nageru_p2.moveAction(DIRECTION_LEFT);
	}
	if( input->checkPress( INPUT_RIGHT, PAD2 ) )
	{
		nageru_p2.moveAction(DIRECTION_RIGHT);
	}
	nageru_p2.normSpd();
	//{^
	//XbV
	if( !input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_1, PAD2 ) )
	{
		throwBlockID = nageru_p2.doAttack(DB->systemDB.getScene());
		if(throwBlockID != 9999 )
		{
			field.blockLost(throwBlockID, 2 );
		}
	}
	//X[
	if( !input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_2, PAD2 ) )
	{
		throwBlockID = nageru_p2.doThrow(DB->systemDB.getScene());
		if(throwBlockID != 9999 )
		{
			nageru_p2.startCalcThrowBlockDistance(throwBlockID);
			nageru_p2.entryVSThrowBlock(throwBlockID  % 1000);

			blockSpd = nageru_p1.getPos() - nageru_p2.getPos();
			blockSpd.normalize();
			field.blockThrow( throwBlockID, nageru_p2.getPos() ,blockSpd * 3 );
			nageru_p2.setThrowSpd(blockSpd);

			sound.playThrowSE(DB);
		}
	}
	//Wv
	if( !input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_3, PAD2 ) )
	{
		if(nageru_p2.getMovingBase().canJump == true )
		{
			nageru_p2.jumpAction(false);
			sound.playJumpSE(DB);
		}
	}
	//tg
	if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
	{
		if(standBlockID >= 1000 && standBlockID != 9999 && nageru_p1.getStatusBase().stock < 6 )
		{
			field.blockLift( standBlockID - 1000);
			nageru_p1.entryLiftBlock( DB->systemDB.getScene(), standBlockID - 1000 );
			nageru_p1.jumpAction(true);
			sound.playLiftSE(DB);
		}
	}
	if( input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_1, PAD2 ) )
	{
		if(nageru_p2.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_RUSH;
			nageru_p2.summonAnima(DB, ino_motionStatus );
			sound.playSummonAnimaSE(DB);
		}
	}
	if( input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_2, PAD2 ) )
	{
		if(nageru_p2.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_THROW;
			nageru_p2.summonAnima(DB, ino_motionStatus );
			nageru_p2.setThrowFocus(nageru_p1.getPos() );
			sound.playSummonAnimaSE(DB);
		}
	}
	if( input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_3, PAD2 ) )
	{
		if(nageru_p2.getStatusBase().anima >= 1.0 )
		{
			ino_motionStatus = INO_CURE;
			nageru_p2.summonAnima(DB, ino_motionStatus );	
			effect_p2.heal.effectSet(DB, nageru_p2.getPModel());
			sound.playSummonAnimaSE(DB);
		}
	}
	//Aj}yA
	if( input->checkPress( INPUT_5, PAD2 ) && input->checkDown( INPUT_4, PAD2 ) )
	{
		if(nageru_p2.getStatusBase().anima >= 1.0 )
		{
			for(int i=0 ; i<10; i++ )
			{
				repairID[i] = -1;
			}
			field.blockRevival(2, repairID);
			for(int i=0 ; i<10; i++ )
			{
				if( repairID[i] > -1 )
				{
					effect_p2.repair.effectSet(DB, field.getModel(repairID[i] ));
				}
			}
			sound.playSummonAnimaSE(DB);

			ino_motionStatus = INO_REPAIR;
			nageru_p2.summonAnima(DB, ino_motionStatus );
		}
	}
	if(input->checkPress( INPUT_SELECT, PAD2) && input->checkPress( INPUT_START, PAD2)  )
		{
			DB->systemDB.fade( -100 );
			sound.stopMainBGM(DB);
			sound.stopRockingBGM(DB);
			sound.stopBontaBGM(DB);
			nageru_p1.removeIno(DB, true);
			nageru_p2.removeIno(DB, true);
			*scene = S_TITLE;
			return true;
		}
	
	nageru_p2.setGravity();
	nageru_p2.moveAttack();
	nageru_p2.addAcc();
	nageru_p2.dashAction();

	//P2F΃XbV@Փ˔
	if(nageru_p1.getAttackFlag() == true &&
		DB->modelDB.checkCollision("nageru_p2", nageru_p1.getAttackPObb(), &zeroSpd ) )
	{
		effect_p1.slash.effectSet(DB, nageru_p1.getPAttackModel() );

		nageru_p1.setAttackFlag(false );
		nageru_p1.addCombo();
		nageru_p2.setDamage(nageru_p1.getAttackDamage(), 5 );
		sound.playSlashSE(DB);
		nageru_p1.plusAnimaGauge(0.02);
	}
	//P2F΃X[@Փ˔
	hitThrowBlockID = field.checkCollision( DB->modelDB.getOBB("nageru_p2") , nageru_p1.getPThrowSpd(), 3 )  % 1000;
	if(hitThrowBlockID != 999 && nageru_p2.checkHitVSThrowBlockID(hitThrowBlockID) == true)
	{
		nageru_p1.removeVSThrowBlockID(hitThrowBlockID);
		
		effect_p1.throwHit.effectSet(DB, field.getModel(hitThrowBlockID));
		nageru_p1.addCombo();
		nageru_p1.stopCalcThrowBlockDistance(hitThrowBlockID );
		field.blockLost(hitThrowBlockID, 1);
		nageru_p2.setDamage(nageru_p1.getThrowDamage(), 0 );
		sound.playEnemyDamageSE(DB);
		nageru_p1.plusAnimaGauge(0.01);
	}
	//P2F΃Aj}bV@Փ˔
	if(nageru_p1.getAnimaRushFlag() == true &&
		DB->modelDB.checkCollision("nageru_p2", "ino_p1", &zeroSpd ) )
	{
		effect_p1.rush.effectSet(DB, nageru_p2.getPModel() );

		nageru_p1.addCombo();
		nageru_p1.setAnimaRushFlag(false);
		nageru_p2.setDamage(nageru_p1.getAnimaRushDamage(), 3 );
		sound.playEnemyDamageSE(DB);
	}
	//P2F΃Aj}X[@Փ˔
	if(nageru_p1.getAnimaThrowFlag() == true &&
		DB->modelDB.checkCollision("nageru_p2", "ino_throw_p1", nageru_p1.getPanimaThrowSpd() ) )
	{
		effect_p1.Animathrow.effectSet(DB, nageru_p1.getPAnimaThrowModel() );

		nageru_p1.addCombo();
		nageru_p1.removeAnimaThrow(DB);
		nageru_p2.setDamage(nageru_p1.getAnimaThrowDamage(), 0 );

		sound.playEnemyDamageSE(DB);
	}
	//P2FP1Փ˔
	DB->modelDB.checkCollision("nageru_p1", "nageru_p2", nageru_p2.getPSpd() ) ;

	//P2FՓ˔
	standBlockID = field.checkCollision( DB->modelDB.getOBB("nageru_p2") , nageru_p2.getPSpd(), 1 );
	if(standBlockID != 9999  )
	{
		nageru_p2.initAcc();
		nageru_p2.motionStateStop();
		field.setStandBlock(standBlockID - 1000, 1);
	}

	if(nageru_p2.setFallState() == true)
	{
		nageru_p2.setDamage( 1, 240 );
		sound.playFallSE(DB);
	}
	nageru_p2.updateFly(DB);

	nageru_p2.translatePlayer(DB);

	nageru_p2.setVecEnemy( nageru_p1.getPos() );
	nageru_p2.motionStateFall();
	nageru_p2.updateDamageMotion();
	nageru_p2.updateDead(DB);
	nageru_p2.updateAnima(DB);
	nageru_p2.updateModel(DB);
	nageru_p2.moveLiftBlock();

	nageru_p2.removeIno(DB, false);

	nageru_p2.plusAnimaGauge(0.001);

	nageru_p2.updateAnimaThrow(DB);
	nageru_p2.updateAttack(DB);
	nageru_p2.updateCombo();
	nageru_p2.stopMotionStatus( DB);	//U[VĨ[V~
	nageru_p2.updateInv();

	field.removeStandBlock(1);


	camera.updateVS( DB->modelDB.getModel( "nageru_p1" )->getPosition(), DB->modelDB.getModel("nageru_p2")->getPosition() );
	

	interFace.setP1_LifeRate(nageru_p1.getStatusBase().life, nageru_p1.getStatusBase().lifeMax);
	interFace.setP1_Stock(nageru_p1.getStatusBase().stock );
	interFace.setP1_Anima(nageru_p1.getStatusBase().anima);
	interFace.setP1_Combo(nageru_p1.getStatusBase().combo);
	interFace.setP2_LifeRate(nageru_p2.getStatusBase().life, nageru_p2.getStatusBase().lifeMax);
	interFace.setP2_Stock(nageru_p2.getStatusBase().stock );
	interFace.setP2_Anima(nageru_p2.getStatusBase().anima);
	interFace.setP2_Combo(nageru_p2.getStatusBase().combo);
	interFace.setTime(int(timer.getTime() * 100 ) );
	interFace.updateGraph(DB);

	field.blockLost( nageru_p1.calcThrowBlockDistance(), 1);
	field.blockLost( nageru_p2.calcThrowBlockDistance(), 2);

	field.update();

	effect_p1.update(DB);
	effect_p2.update(DB);

	if(nageru_p1.getMotionStatus() == 12 || nageru_p1.getMotionStatus() == 13 ||
		nageru_p2.getMotionStatus() == 12 || nageru_p2.getMotionStatus() == 13 )
	{
		if(DB->systemDB.getAlphaPoint() <= 0.6 )
		{
			DB->systemDB.fade( 0.05 );
		}
		else
		{
			DB->graphDB.setPositionLT("continue", -300.0, 120.0);
			DB->graphDB.entryImage("continue");
			DB->graphDB.setPositionLT("yes", -75.0, -25.0);
			DB->graphDB.entryImage("yes");
			DB->graphDB.setPositionLT("no", -75.0, -125.0);
			DB->graphDB.entryImage("no");
			DB->graphDB.setPositionLT("cursor", -75, -25 -100.0*cursorNum );
			DB->graphDB.entryImage("cursor");

			if( input->checkDown( INPUT_UP ) )
			{
				cursorNum --;
				if(cursorNum <= 0 ) cursorNum = 0;
			}
			if( input->checkDown( INPUT_DOWN ) )
			{
				cursorNum ++;
				if(cursorNum >= 1 ) cursorNum = 1;
			}
			if( input->checkDown( INPUT_4 ) )
			{
				if(cursorNum == 0 )
				{
					/*
					DB->systemDB.fade( -100 );
					DB->graphDB.removeImage("continue");
					DB->graphDB.removeImage("yes");
					DB->graphDB.removeImage("no");
					DB->graphDB.removeImage("cursor");

					for(int i=0; i<6; i++ )
					{
						dammyID[i] = nageru_p1.getLiftBlockID(i);
						nageru_p1.doThrow(DB->systemDB.getScene());
						field.blockLost( dammyID[i], 1);
						field.blockRevival(1, dammyID);
					}
					field.deleteField();
					field.loadEditFieldData( 6 , &nageruPos , &enemyPos );

					nageru_p1.init(DB);
					nageru_p2.init(DB);
					nageru_p1.setPos(nageruPos );
					nageru_p2.setPos(enemyPos);

					camera.setFocusToEnemy( nageru_p1.getPos(), nageru_p2.getPos() );
					*/
					return true;
				}
				if(cursorNum == 1 )
				{
					DB->systemDB.fade( -100 );
					sound.stopMainBGM(DB);
					sound.stopRockingBGM(DB);
					sound.stopBontaBGM(DB);
					sound.stopBattleBGM(DB);
					*scene = S_TITLE;
					return true;
				}
			}
		}
	}

	DB->effectDB.glMoveTo("cursor_p1", nageru_p1.getPos().x, nageru_p1.getPos().y+70, nageru_p1.getPos().z);
	DB->effectDB.focusCamera("cursor_p1", DB->systemDB.getCamera() );
	DB->effectDB.glMoveTo("cursor_p2", nageru_p2.getPos().x, nageru_p2.getPos().y+70, nageru_p2.getPos().z);
	DB->effectDB.focusCamera("cursor_p2", DB->systemDB.getCamera() );


	//if(sound.getMainBGMStatus() == true )
	if(sound.getBattleBGMStatus() == true )
	{
		sound.playBattleBGM(DB);
	}

	return false ;
}

/*
//wiǂݍ
*/
void CVSMode::loadBG()
{
	if( !bgTex[0].readPNG( "dat/graph/maingame/bg/bg_under.png" ) )	fl_alert( "error read[bg_under.png]" );
	bgTex[0].setTextureSize( 4096.0 , 4096.0 );
	bgTex[0].setTexRendMode( FK_TEX_REND_NORMAL );
	bgTex[0].setTextureMode( FK_TEX_REPLACE );
	bgModel[0].setShape( &bgTex[0] );
	bgModel[0].glMoveTo( 0.0 , -1010.0 , 0.0 );
	bgModel[0].glFocus( 0.0 , -1025.0 , 0.0 );
	if( !bgTex[5].readPNG( "dat/graph/maingame/bg/bg_over.png" ) )	fl_alert( "error read[bg_over.png]" );
	bgTex[5].setTextureSize( 4096.0 , 4096.0 );
	bgTex[5].setTexRendMode( FK_TEX_REND_NORMAL );
	bgTex[5].setTextureMode( FK_TEX_REPLACE );
	bgModel[5].setShape( &bgTex[5] );
	bgModel[5].glMoveTo( 0.0 , 3060.0 , 0.0 );
	bgModel[5].glFocus( 0.0 , 3080.0 , 0.0 );
	for(int i=1 ; i<5 ; i++)
	{
		if( !bgTex[i].readPNG( "dat/graph/maingame/bg/bg_side.png" ) )
		{
			fl_alert( "error read[bg_side.png]" );
		}
		else
		{
			bgTex[i].setTextureSize( 4096.0 , 4096.0 );
			bgTex[i].setTexRendMode( FK_TEX_REND_SMOOTH );
			bgTex[i].setTextureMode( FK_TEX_REPLACE );
			bgModel[i].setShape( &bgTex[i] );
			if( i == 4 )
			{
				bgModel[1].glMoveTo( 2048.0 , 1024.0 , 0.0 );
				bgModel[2].glMoveTo( 0.0 , 1024.0 , 2048.0 );
				bgModel[3].glMoveTo( -2048.0 , 1024.0 , 0.0 );
				bgModel[4].glMoveTo( 0.0 , 1024.0 , -2048.0 );
				bgModel[1].glFocus( 2050.0 , 1024.0 , 0.0 );
				bgModel[2].glFocus( 0.0 , 1024.0 , 2050.0 );
				bgModel[3].glFocus( -2050.0 , 1024.0 , 0.0 );
				bgModel[4].glFocus( 0.0 , 1024.0 , -2050.0 );
			}
		}
	}

	for(int i =0; i<5; i++ )
	{
		DB->systemDB.getScene()->entryModel( &bgModel[i] );
	}
}
