//-------------------------------------------
// Q[{
//-------------------------------------------

#include "gameMain.h"
#include "title.h"
#include "option.h"
#include "singleMode.h"
#include "VSMode.h"
#include "charaSelect.h"
#include "stageEditor.h"

CGameMain::CGameMain()
{
	gameScene = NULL ;
	sceneType = S_TITLE ;
	sceneChange = false ;
	fk_Material::initDefault();
}

CGameMain::~CGameMain()
{
	deleteScene();
	input.saveCode( "keyConfig.dat" );
	db.configDB.saveConfig( "config.ini" );
	db.rankingDB.saveRanking( "ranking.dat" );
}

/*
 
 */
void CGameMain::init( Fl_Window *lw , fk_Window *kw )
{
	mainWindow = lw ;
	window = kw ;
	mainWindow->show();
	window->show();
	window->setScene( &scene );
	lightModel.setShape( &light );
	lightModel.setMaterial( White );
	lightModel.getMaterial()->setAmbDiff( 1.0 , 1.0 , 1.0 );
	lightModel.glMoveTo( 0.0 , 0.0 , 0.0 );
	lightModel.glFocus( 0.5 , -1.0 , 0.0 );
	scene.entryModel( &lightModel );
	scene.entryCamera( &camera );
	scene.setBlendStatus( true );
	db.systemDB.init( mainWindow , window , &scene , &camera );
	db.configDB.loadConfig( "config.ini" );
	db.modelDB.setAddress( &scene );
	db.effectDB.setAddress( &scene );
	db.graphDB.setAddress( window , &scene );
	db.soundDB.changeVolume( db.configDB.getBgmVolume() , db.configDB.getSeVolume() );
	input.init( mainWindow , window );
	changeScene();
	db.rankingDB.loadRanking( "ranking.dat" );
}

/*
 VV[̍쐬
 */
void CGameMain::changeScene()
{
	scene.clearDisplay();
	window->setScene( NULL );
	deleteScene();
	window->setScene( &scene );
	scene.entryModel( &lightModel );
	scene.entryCamera( &camera );
	db.graphDB.deleteImageAll();
	db.modelDB.deleteModelAll();
	db.effectDB.deleteEffectAll();
	db.systemDB.init( mainWindow , window , &scene , &camera );
	switch( sceneType )
	{
	case S_TITLE:
		gameScene = new CTitle();
		break ;
	case S_OPTION:
		gameScene = new COption();
		break ;
	case S_SINGLEMODE:
		gameScene = new CSingleMode();
		break ;
	case S_VSMODE:
		gameScene = new CVSMode();
		break ;
	case S_CHARASELECT:
		gameScene = new CCharaSelect();
		break ;
	case S_STAGEEDITOR:
		gameScene = new CStageEditor();
		break ;
	default:
		fl_alert( "Not defined sceneType." );
		gameScene = new CTitle();
	}
	gameScene->setAddress( &sceneType , &db , &input );
	gameScene->init();
}

/*
 V[̍폜
 */
void CGameMain::deleteScene()
{
	if( gameScene != NULL )
	{
		delete gameScene ;
		gameScene = NULL ;
	}
}

/*
 Q[̒
 */
void CGameMain::game()
{
	//db.soundDB.loadBGM( "test" , "dat/bgm/test.ogg" );
	//db.graphDB.setImage( "test" , "dat/graph/test.png" );
	//db.graphDB.setPositionLT( "test" , -WINDOW_WIDTH/2.0 , WINDOW_HEIGHT/2.0 );

	while( 1 )
	{
		fc.TimeRegular();
		if( !mainWindow->visible() )
		{
			if( !Fl::wait() )
			{
				break ;
			}
			else
			{
				continue ;
			}
		}
		if( !Fl::check() )
		{
			break ;
		}
		if( !window->winOpenStatus() )
		{
			continue ;
		}

		input.update();
		sceneChange = gameScene->onPeriod();
		if( sceneType == S_END )
		{
			break ;
		}
		if( sceneChange )
		{
			changeScene();
		}
		if( fc.GetDrawFlag() )
		{
			window->drawWindow();
		}

		/*
		if( input.checkDown( INPUT_2 ) )
		{
			db.graphDB.setString( "test" , "eXg" );
		}
		*/
		/*  eXgp */
		/*
		if( input.checkPress( INPUT_UP ) )
		{
			db.systemDB.fade( 0.005 );
		}
		else if( input.checkPress( INPUT_DOWN ) )
		{
			db.systemDB.fade( -0.005 );
		}
		*/
		//db.systemDB.frameTime();
		/*
		if( input.checkUp( INPUT_2 ) )
		{
			db.soundDB.stopBGM( "test" );	// AŌĂԁ[voO
		}
		else
		{
			db.soundDB.playBGM( "test" );
		}
		db.soundDB.playBGM( "test2" );*/
	}
}
