//---------------------------------------------------
// VO[h
//---------------------------------------------------

#include "singleMode.h"

CSingleMode::CSingleMode()
{
}

CSingleMode::~CSingleMode()
{
	field.deleteField();
	nageru.deleteModel(DB);
	rocking.deleteModel(DB);
	interFace.deleteImage(DB);
	sound.deleteSound(DB);
}

void CSingleMode::init()
{
	camera.setAddress(DB->systemDB.getCamera());
	cameraMode = DB->configDB.getCameraMode();

	loadBG();

	interFace.setGraph(DB);
	interFace.removeNageru_P2_Icon(DB);
	interFace.setHelp(DB,false);
	timer.initTime();
	nageru.loadModel(DB, "nageru", "ino", "ino_throw", "return");
	nageru.init(DB);

	rocking.loadModel(DB);
	rocking.init();

	field.setAddress( DB->systemDB.getScene() );

	field.loadEditFieldData( 6 , &nageruPos , &enemyPos );
	nageru.setPos(nageruPos );
	rocking.setPos(enemyPos);


	effect.init(DB);

	
	sound.init(DB);
	sound.playBontaBGM(DB);

	for(int i=0; i<10; i++ )
	{
		repairID[i] = -1;
	}

	standBlockID = 9999;

	DB->graphDB.setImage("tutorial1", "dat/graph/tutorial/01_move.png" );
	DB->graphDB.setPositionLT("tutorial1", -400.0, 225.0 );
	DB->graphDB.setImage("tutorial2", "dat/graph/tutorial/02_jump.png" );
	DB->graphDB.removeImage("tutorial2");
	DB->graphDB.setImage("tutorial3", "dat/graph/tutorial/03_lift.png" );
	DB->graphDB.removeImage("tutorial3");
	DB->graphDB.setImage("tutorial4", "dat/graph/tutorial/04_attack.png" );
	DB->graphDB.removeImage("tutorial4");
	DB->graphDB.setImage("tutorial5", "dat/graph/tutorial/05_anima1.png" );
	DB->graphDB.removeImage("tutorial5");
	DB->graphDB.setImage("tutorial6", "dat/graph/tutorial/06_anima2.png" );
	DB->graphDB.removeImage("tutorial6");
	DB->graphDB.setImage("tutorial7", "dat/graph/tutorial/07_end.png" );
	DB->graphDB.removeImage("tutorial7");

	DB->graphDB.setImage("stageClear", "dat/graph/maingame/stageClear.png" );
	DB->graphDB.removeImage("stageClear");
	DB->graphDB.setImage("gameOver", "dat/graph/maingame/gameover.png" );
	DB->graphDB.removeImage("gameOver");
	DB->graphDB.setImage("continue", "dat/graph/maingame/continue.png");
	DB->graphDB.removeImage("continue");
	DB->graphDB.setImage("rank_in", "dat/graph/maingame/rank_in.png");
	DB->graphDB.removeImage("rank_in");
	DB->graphDB.setImage("yes", "dat/graph/maingame/yes.png");
	DB->graphDB.removeImage("yes");
	DB->graphDB.setImage("no", "dat/graph/maingame/no.png");
	DB->graphDB.removeImage("no");
	DB->graphDB.setImage("cursor", "dat/graph/interface/cursor.png");
	DB->graphDB.removeImage("cursor");

	DB->graphDB.setImage("staffroll_1", "dat/graph/maingame/lifthrow_staff_01.png");
	DB->graphDB.removeImage("staffroll_1");
	DB->graphDB.setImage("staffroll_2", "dat/graph/maingame/lifthrow_staff_02.png");
	DB->graphDB.removeImage("staffroll_2");
	DB->graphDB.setImage("staffroll_3", "dat/graph/maingame/lifthrow_staff_03.png");
	DB->graphDB.removeImage("staffroll_3");

	cursorNum = 0;

	stageNum = 0;
	tutorialStep = 1;
	reqCount = 100;

	clearFlag = false;
	endingStep = 0;

	zeroSpd = fk_Vector(0.0, 0.0, 0.0);
}


bool CSingleMode::onPeriod()
{
	if(stageNum == 0 )
	{
		field.setShadow( true , nageru.getPos() , 10.0 );
		field.setShadow( false , rocking.getPos() , 60.0 );

		switch(tutorialStep)
		{
		case 1:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial1");
				DB->graphDB.setPositionLT("tutorial2", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial2");
			}
			break;

		case 2:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial2");
				DB->graphDB.setPositionLT("tutorial3", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial3");
			}
			break;

		case 3:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial3");
				DB->graphDB.setPositionLT("tutorial4", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial4");
			}
			break;

		case 4:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial4");
				DB->graphDB.setPositionLT("tutorial5", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial5");
			}
			break;

		case 5:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial5");
				DB->graphDB.setPositionLT("tutorial6", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial6");
			}
			break;

		case 6:
			if(reqCount <= 0 )
			{
				reqCount = 2;
				tutorialStep ++;
				DB->graphDB.removeImage("tutorial6");
				DB->graphDB.setPositionLT("tutorial7", -400.0, 225.0 );
				DB->graphDB.entryImage("tutorial7");
			}
			break;

		case 7:
			break;

		default :
			break;

		}

		nageru.motionStateStand();


		nageru.setView(DB->systemDB.getCamera()->getVec() );
		nageru.initSpd();

		if( input->checkPress( INPUT_UP  ) )
		{
			nageru.moveAction(DIRECTION_UP);
			if(tutorialStep == 1 )
				{
					reqCount --;
				}
		}
		if( input->checkPress( INPUT_DOWN ) )
		{
			nageru.moveAction(DIRECTION_DOWN);
			if(tutorialStep == 1 )
				{
					reqCount --;
				}
		}
		if( input->checkPress( INPUT_LEFT  ) )
		{
			nageru.moveAction(DIRECTION_LEFT);
			if(tutorialStep == 1 )
				{
					reqCount --;
				}
		}
		if( input->checkPress( INPUT_RIGHT ) )
		{
			nageru.moveAction(DIRECTION_RIGHT);
			if(tutorialStep == 1 )
				{
					reqCount --;
				}
		}
		nageru.normSpd();
		//{^
		//XbV
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
		{
			throwBlockID = nageru.doAttack(DB->systemDB.getScene());
			if(throwBlockID != 9999 )
			{
				field.blockLost(throwBlockID, 1 );
				if(tutorialStep == 4 )
				{
					reqCount --;
				}
			}
		}
		//X[
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
		{
			throwBlockID = nageru.doThrow(DB->systemDB.getScene());
			if(throwBlockID != 9999 )
			{
				nageru.startCalcThrowBlockDistance(throwBlockID);

				blockSpd = rocking.getPos() - nageru.getPos();
				blockSpd.normalize();
				field.blockThrow( throwBlockID, nageru.getPos() ,blockSpd * 3 );
				nageru.setThrowSpd(blockSpd);

				sound.playThrowSE(DB);

				if(tutorialStep == 4 )
				{
					reqCount --;
				}
			}
		}
		//Wv
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
		{
			if(nageru.getMovingBase().canJump == true )
			{
				nageru.jumpAction(false);
				sound.playJumpSE(DB);

				if(tutorialStep == 2 )
				{
					reqCount --;
				}
			}
		}
		//tg
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
		{
			if(standBlockID >= 1000 && standBlockID != 9999 && nageru.getStatusBase().stock < 6 )
			{
				field.blockLift( standBlockID - 1000);
				nageru.entryLiftBlock( DB->systemDB.getScene(), standBlockID - 1000 );
				nageru.jumpAction(true);
				sound.playLiftSE(DB);

				if(tutorialStep == 3 )
				{
					reqCount --;
				}
			}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
		{
			ino_motionStatus = INO_RUSH;
			nageru.summonAnima(DB, ino_motionStatus );
			sound.playSummonAnimaSE(DB);

			if(tutorialStep == 5 )
				{
					reqCount --;
				}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
		{
			ino_motionStatus = INO_THROW;
			nageru.summonAnima(DB, ino_motionStatus );
			nageru.setThrowFocus(rocking.getPos() );
			sound.playSummonAnimaSE(DB);

			if(tutorialStep == 5 )
				{
					reqCount --;
				}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
		{
			ino_motionStatus = INO_CURE;
			nageru.summonAnima(DB, ino_motionStatus );	
			effect.heal.effectSet(DB, nageru.getPModel());
			sound.playSummonAnimaSE(DB);

			if(tutorialStep == 6 )
				{
					reqCount --;
				}
		}
		//Aj}yA
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
		{
			for(int i=0 ; i<10; i++ )
			{
				repairID[i] = -1;
			}
			field.blockRevival(1, repairID);
			for(int i=0 ; i<10; i++ )
			{
				if( repairID[i] > -1 )
				{
					effect.repair.effectSet(DB, field.getModel(repairID[i] ));
				}
			}
			sound.playSummonAnimaSE(DB);

			ino_motionStatus = INO_REPAIR;
			nageru.summonAnima(DB, ino_motionStatus );

			if(tutorialStep == 6 )
				{
					reqCount --;
				}
		}
		if( input->checkDown( INPUT_START ) )
		{
			DB->graphDB.removeImage("tutorial1");
			DB->graphDB.removeImage("tutorial2");
			DB->graphDB.removeImage("tutorial3");
			DB->graphDB.removeImage("tutorial4");
			DB->graphDB.removeImage("tutorial5");
			DB->graphDB.removeImage("tutorial6");
			DB->graphDB.removeImage("tutorial7");
			stageNum ++;
			tutorialStep = 0;
		}
		nageru.setGravity();
		nageru.moveAttack();
		nageru.addAcc();
		nageru.dashAction();
		//iQF΃bNLOՓ˔
		if(DB->modelDB.checkCollision("rocking", "nageru", nageru.getPSpd() ) )
		{
			if(rocking.getMotionStatus() == 4 || rocking.getMotionStatus() == 5 )
			{
				nageru.setDamage(1, 20 );
				if(nageru.getInv() == 0 )
				{
					effect.damage.effectSet(DB, nageru.getPModel() );
					sound.playDamageSE(DB);
				}
			}
		}
		//Ƃ̏Փ˔
		standBlockID = field.checkCollision( DB->modelDB.getOBB("nageru") , nageru.getPSpd(), 1 );
		if(standBlockID != 9999  )
		{
			nageru.initAcc();
			nageru.motionStateStop();
			field.setStandBlock(standBlockID - 1000, 1);
		}
		else
		{
			field.removeStandBlock(1);
		}

		if(nageru.setFallState() == true)
		{
			sound.playFallSE(DB);
		}
		nageru.updateFly(DB);

		nageru.translatePlayer(DB);

		nageru.setVecEnemy( rocking.getPos() );
		nageru.motionStateFall();
		nageru.updateDamageMotion();
		nageru.updateDead(DB);
		nageru.updateAnima(DB);
		nageru.updateModel(DB);
		nageru.moveLiftBlock();
		rocking.moveLiftBlock();

		nageru.removeIno(DB, false);


		nageru.plusAnimaGauge(0.1);
		rocking.plusAnimaGauge(0.1);

		nageru.updateAnimaThrow(DB);
		nageru.updateAttack(DB);
		nageru.updateCombo();
		nageru.stopMotionStatus( DB);	//U[VĨ[V~
		nageru.updateInv();

		//bNLOFΑ@Փ˔
		rocking.setHitBlock(false);
		if(field.checkCollision( DB->modelDB.getOBB("rocking") , rocking.getPSpd(), 1 ) != 9999)
		{
			rocking.setHitBlock(true);
		}
		//bNLOF΃XbV@Փ˔
		if(nageru.getAttackFlag() == true &&
			DB->modelDB.checkCollision("rocking", nageru.getAttackPObb(), &zeroSpd ) )
		{
			effect.rush.effectSet(DB, nageru.getPAttackModel() );

			nageru.setAttackFlag(false );
			nageru.addCombo();
			sound.playSlashSE(DB);
		}
		//bNLOF΃X[@Փ˔
		hitThrowBlockID = field.checkCollision( DB->modelDB.getOBB("rocking") , nageru.getPThrowSpd(), 3 )  % 1000;
		if(hitThrowBlockID != 999)
		{
			effect.throwHit.effectSet(DB, field.getModel(hitThrowBlockID));
			nageru.addCombo();
			nageru.stopCalcThrowBlockDistance(hitThrowBlockID );
			field.blockLost(hitThrowBlockID, 1);
			sound.playEnemyDamageSE(DB);
		}
		//bNLOF΃Aj}bV@Փ˔
		if(nageru.getAnimaRushFlag() == true &&
			DB->modelDB.checkCollision("rocking", "ino", &zeroSpd ) )
		{
			effect.rush.effectSet(DB, rocking.getPModel() );

			nageru.addCombo();
			nageru.setAnimaRushFlag(false);
			sound.playEnemyDamageSE(DB);
		}
		//bNLOF΃Aj}X[@Փ˔
		if(nageru.getAnimaThrowFlag() == true &&
			DB->modelDB.checkCollision("rocking", "ino_throw", nageru.getPanimaThrowSpd() ) )
		{
			effect.Animathrow.effectSet(DB, nageru.getPAnimaThrowModel() );

			nageru.addCombo();
			nageru.removeAnimaThrow(DB);

			sound.playEnemyDamageSE(DB);
		}
		rocking.translatePlayer(DB);
		rocking.updateRushBlock(DB);
		rocking.updateModel(DB);
		rocking.updateInv();
		rocking.moveLimit();


		camera.updateSingle( DB->modelDB.getModel( "nageru" )->getPosition() );
		//camera.updateVS( DB->modelDB.getModel( "nageru" )->getPosition(), DB->modelDB.getModel("rocking")->getPosition() );
		camera.addHeight( double(input->checkStick().rightY )/400 );
		camera.addAngle( double(input->checkStick().rightX )/500 * (PI/180) );
		if(cameraMode == 0 )
		{
			camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
		}
		else
		{
			if(input->checkPress( INPUT_6 ) )
			{
				camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
			}
		}


		interFace.setP1_LifeRate(nageru.getStatusBase().life, nageru.getStatusBase().lifeMax);
		interFace.setP1_Stock(nageru.getStatusBase().stock );
		interFace.setP1_Anima(nageru.getStatusBase().anima);
		interFace.setP1_Combo(nageru.getStatusBase().combo);
		interFace.setP2_LifeRate(rocking.getStatusBase().life, rocking.getStatusBase().lifeMax);
		interFace.setP2_Stock(rocking.getStatusBase().stock );
		interFace.setP2_Anima(rocking.getStatusBase().anima);
		interFace.setP2_Combo(rocking.getStatusBase().combo);
		interFace.setTime(int(timer.getTime() * 100 ) );
		interFace.updateGraph(DB);

		field.blockLost( nageru.calcThrowBlockDistance(), 1);
		field.update();

		effect.update(DB);

		if(nageru.getMotionStatus() == 12 || nageru.getMotionStatus() == 13 )
		{
			if(DB->systemDB.getAlphaPoint() <= 0.6 )
			{
				DB->systemDB.fade( 0.05 );
			}
			else
			{
				DB->graphDB.setPositionLT("gameOver", -130.0, 170.0);
				DB->graphDB.entryImage("gameOver");
				DB->graphDB.setPositionLT("continue", -300.0, 120.0);
				DB->graphDB.entryImage("continue");
				DB->graphDB.setPositionLT("yes", -75.0, -25.0);
				DB->graphDB.entryImage("yes");
				DB->graphDB.setPositionLT("no", -75.0, -125.0);
				DB->graphDB.entryImage("no");
				DB->graphDB.setPositionLT("cursor", -75, -25 -100.0*cursorNum );
				DB->graphDB.entryImage("cursor");

				if( input->checkDown( INPUT_UP ) )
				{
					cursorNum --;
					if(cursorNum <= 0 ) cursorNum = 0;
				}
				if( input->checkDown( INPUT_DOWN ) )
				{
					cursorNum ++;
					if(cursorNum >= 1 ) cursorNum = 1;
				}
				if( input->checkDown( INPUT_4 ) )
				{
					if(cursorNum == 0 )
					{
						DB->systemDB.fade( -100 );
						DB->graphDB.removeImage("gameOver");
						DB->graphDB.removeImage("continue");
						DB->graphDB.removeImage("yes");
						DB->graphDB.removeImage("no");
						DB->graphDB.removeImage("cursor");
						nageru.init(DB);
						rocking.init();
						nageru.setPos(nageruPos );
						rocking.setPos(enemyPos);
						tutorialStep = 0;
					}
					if(cursorNum == 1 )
					{
						*scene = S_TITLE;
						return true;
					}
				}
			}
		}

		if(rocking.getMotionStatus() == 11 )
		{
			if(DB->systemDB.getAlphaPoint() <= 0.6 )
			{
				DB->systemDB.fade( 0.05 );
			}
			else
			{
				DB->graphDB.setPositionLT("stageClear", -145.0, 100.0);
				DB->graphDB.entryImage("stageClear");
				DB->graphDB.setPositionLT("rank_in", -270.0, 10.0);
				DB->graphDB.entryImage("rank_in");


				if( input->checkDown( INPUT_4 ) )
				{
					DB->systemDB.fade( -100 );
					//DB->graphDB.removeImage("stageClear");
					//DB->graphDB.removeImage("rank_in");
					*scene = S_TITLE;
					return true;
				}
			}
		}

		if(sound.getBontaBGMStatus() == true )
		{
			sound.playBontaBGM(DB);
		}
	}
	else if(stageNum == 1 )
	{
		if(tutorialStep == 0)
		{
			DB->systemDB.fade( 0.05 );
			if(DB->systemDB.getAlphaPoint() >= 1.0 )
			{
				for(int i=0; i<6; i++ )
				{
					dammyID[i] = nageru.getLiftBlockID(i);
					nageru.doThrow(DB->systemDB.getScene());
					field.blockLost( dammyID[i], 1);
					field.blockRevival(1, dammyID);
				}
				field.deleteField();
				field.loadEditFieldData( 6 , &nageruPos , &enemyPos );
				nageru.init(DB);
				rocking.init();
				field.blockRevival(1, dammyID);
				nageru.setPos(nageruPos );
				rocking.setPos(enemyPos);
				camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
				interFace.setHelp(DB,true);
				nageru.removeIno(DB, true);
				tutorialStep ++;
			}
		}
		else
		{
			DB->systemDB.fade( -0.05 );
			if(DB->systemDB.getAlphaPoint() <= 0.0 )
			{
				tutorialStep = 0;
				stageNum ++;
				sound.stopBontaBGM(DB);
				sound.playRockingBGM(DB);
			}
		}
	}
	else if(stageNum == 2 )
	{
		field.setShadow( true , nageru.getPos() , 10.0 );
		field.setShadow( false , rocking.getPos() , 60.0 );

		if(rocking.getMotionStatus() != 11 && rocking.getMotionStatus() != 12 &&
			nageru.getMotionStatus() != 12 && nageru.getMotionStatus() != 13)
		{
			timer.addTime(0.0166666667);
		}

		nageru.motionStateStand();


		nageru.setView(DB->systemDB.getCamera()->getVec() );
		nageru.initSpd();

		if( input->checkPress( INPUT_UP  ) )
		{
			nageru.moveAction(DIRECTION_UP);
		}
		if( input->checkPress( INPUT_DOWN ) )
		{
			nageru.moveAction(DIRECTION_DOWN);
		}
		if( input->checkPress( INPUT_LEFT  ) )
		{
			nageru.moveAction(DIRECTION_LEFT);
		}
		if( input->checkPress( INPUT_RIGHT ) )
		{
			nageru.moveAction(DIRECTION_RIGHT);
		}
		nageru.normSpd();
		//{^
		//XbV
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
		{
			throwBlockID = nageru.doAttack(DB->systemDB.getScene());
			if(throwBlockID != 9999 )
			{
				field.blockLost(throwBlockID, 1 );
			}
		}
		//X[
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
		{
			throwBlockID = nageru.doThrow(DB->systemDB.getScene());
			if(throwBlockID != 9999 )
			{
				nageru.startCalcThrowBlockDistance(throwBlockID);

				blockSpd = rocking.getPos() - nageru.getPos();
				blockSpd.normalize();
				field.blockThrow( throwBlockID, nageru.getPos() ,blockSpd * 3 );
				nageru.setThrowSpd(blockSpd);

				sound.playThrowSE(DB);
			}
		}
		//Wv
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
		{
			if(nageru.getMovingBase().canJump == true )
			{
				nageru.jumpAction(false);
				sound.playJumpSE(DB);
			}
		}
		//tg
		if( !input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
		{
			if(standBlockID >= 1000 && standBlockID != 9999 && nageru.getStatusBase().stock < 6 )
			{
				field.blockLift( standBlockID - 1000);
				nageru.entryLiftBlock( DB->systemDB.getScene(), standBlockID - 1000 );
				nageru.jumpAction(true);
				sound.playLiftSE(DB);
			}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_1 ) )
		{
			if(nageru.getStatusBase().anima >= 1.0 )
			{
			ino_motionStatus = INO_RUSH;
			nageru.summonAnima(DB, ino_motionStatus );
			sound.playSummonAnimaSE(DB);
			}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_2 ) )
		{
			if(nageru.getStatusBase().anima >= 1.0 )
			{
			ino_motionStatus = INO_THROW;
			nageru.summonAnima(DB, ino_motionStatus );
			nageru.setThrowFocus(rocking.getPos() );
			sound.playSummonAnimaSE(DB);
			}
		}
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_3 ) )
		{
			if(nageru.getStatusBase().anima >= 1.0 )
			{
			ino_motionStatus = INO_CURE;
			nageru.summonAnima(DB, ino_motionStatus );	
			effect.heal.effectSet(DB, nageru.getPModel());
			sound.playSummonAnimaSE(DB);
			}
		}
		//Aj}yA
		if( input->checkPress( INPUT_5 ) && input->checkDown( INPUT_4 ) )
		{
			if(nageru.getStatusBase().anima >= 1.0 )
			{
			for(int i=0 ; i<10; i++ )
			{
				repairID[i] = -1;
			}
			field.blockRevival(1, repairID);
			for(int i=0 ; i<10; i++ )
			{
				if( repairID[i] > -1 )
				{
					effect.repair.effectSet(DB, field.getModel(repairID[i] ));
				}
			}
			sound.playSummonAnimaSE(DB);

			ino_motionStatus = INO_REPAIR;
			nageru.summonAnima(DB, ino_motionStatus );
			}
		}
		if( input->checkDown( INPUT_SELECT ))
		{
			if(interFace.getHelp() == true )
			{
				interFace.setHelp(DB,false);
			}
			else
			{
				interFace.setHelp(DB,true);
			}
		}
		if(input->checkPress( INPUT_SELECT) && input->checkPress( INPUT_START)  )
		{
			DB->systemDB.fade( -100 );
			sound.stopMainBGM(DB);
			sound.stopRockingBGM(DB);
			sound.stopBontaBGM(DB);
			nageru.removeIno(DB, true);
			*scene = S_TITLE;
			return true;
		}

		nageru.setGravity();
		nageru.moveAttack();
		nageru.addAcc();
		nageru.dashAction();
		//iQF΃bNLObVՓ˔
		if(rocking.getRushHitFlag() == true && DB->modelDB.checkCollision("nageru", rocking.getPRushOBB(), &zeroSpd ) )
		{
			rocking.setRushHitFlag(false);
			if(nageru.getInv() == 0 )
			{
					effect.damage.effectSet(DB, nageru.getPModel() );
					sound.playDamageSE(DB);
			}
			nageru.setDamage(1, 6 );
		}
		//iQFΏՌgՓ˔
		for(int i=0; i < rocking.getShockwaveNum() ;i++ )
		{
			if(rocking.getShockwaveHitFlag(i) == true && 
				DB->modelDB.checkCollision("nageru", rocking.getPShockwaveOBB(i), &zeroSpd ) )
			{
				rocking.removeShockwave(DB, i);
				if(nageru.getInv() == 0 )
				{
					effect.damage.effectSet(DB, nageru.getPModel() );
					sound.playDamageSE(DB);
				}
				nageru.setDamage(1, 3 );
			}
		}
		//iQF΃bNLOՓ˔
		if(DB->modelDB.checkCollision("rocking", "nageru", nageru.getPSpd() ) )
		{
			if(rocking.getMotionStatus() == 4 || rocking.getMotionStatus() == 5 )
			{
				if(nageru.getInv() == 0 )
				{
					sound.playDamageSE(DB);
					effect.damage.effectSet(DB, nageru.getPModel() );
				}
				nageru.setDamage(1, 20 );	
			}
		}
		//Ƃ̏Փ˔
		standBlockID = field.checkCollision( DB->modelDB.getOBB("nageru") , nageru.getPSpd(), 1 );
		if(standBlockID != 9999  )
		{
			nageru.initAcc();
			nageru.motionStateStop();
			field.setStandBlock(standBlockID - 1000, 1);
		}
		else
		{
			field.removeStandBlock(1);
		}

		if(nageru.setFallState() == true)
		{
			nageru.setDamage( 4, 240 );
			sound.playFallSE(DB);
		}
		nageru.updateFly(DB);

		nageru.translatePlayer(DB);

		nageru.setVecEnemy( rocking.getPos() );
		nageru.motionStateFall();
		nageru.updateDamageMotion();
		nageru.updateDead(DB);
		nageru.updateAnima(DB);
		nageru.updateModel(DB);
		nageru.moveLiftBlock();
		rocking.moveLiftBlock();

		nageru.removeIno(DB, false);


		nageru.plusAnimaGauge(0.001);
		rocking.plusAnimaGauge(0.1);

		nageru.updateAnimaThrow(DB);
		nageru.updateAttack(DB);
		nageru.updateCombo();
		nageru.stopMotionStatus( DB);	//U[VĨ[V~
		nageru.updateInv();

		//bNLOFΑ@Փ˔
		rocking.setHitBlock(false);
		if(field.checkCollision( DB->modelDB.getOBB("rocking") , rocking.getPSpd(), 1 ) != 9999)
		{
			rocking.setHitBlock(true);
		}
		//bNLOF΃XbV@Փ˔
		if(nageru.getAttackFlag() == true &&
			DB->modelDB.checkCollision("rocking", nageru.getAttackPObb(), &zeroSpd ) )
		{
			effect.rush.effectSet(DB, nageru.getPAttackModel() );

			nageru.setAttackFlag(false );
			nageru.addCombo();
			rocking.setDamage(nageru.getAttackDamage(), 5 );
			sound.playSlashSE(DB);
			nageru.plusAnimaGauge(0.02);
		}
		//bNLOF΃X[@Փ˔
		hitThrowBlockID = field.checkCollision( DB->modelDB.getOBB("rocking") , nageru.getPThrowSpd(), 3 )  % 1000;
		if(hitThrowBlockID != 999)
		{
			effect.throwHit.effectSet(DB, field.getModel(hitThrowBlockID));
			nageru.addCombo();
			nageru.stopCalcThrowBlockDistance(hitThrowBlockID );
			field.blockLost(hitThrowBlockID, 1);
			rocking.setDamage(nageru.getThrowDamage(), 0 );
			sound.playEnemyDamageSE(DB);
			nageru.plusAnimaGauge(0.01);
		}
		//bNLOF΃Aj}bV@Փ˔
		if(nageru.getAnimaRushFlag() == true &&
			DB->modelDB.checkCollision("rocking", "ino", &zeroSpd ) )
		{
			effect.rush.effectSet(DB, rocking.getPModel() );

			nageru.addCombo();
			nageru.setAnimaRushFlag(false);
			rocking.setDamage(nageru.getAnimaRushDamage(), 3 );
			sound.playEnemyDamageSE(DB);
		}
		//bNLOF΃Aj}X[@Փ˔
		if(nageru.getAnimaThrowFlag() == true &&
			DB->modelDB.checkCollision("rocking", "ino_throw", nageru.getPanimaThrowSpd() ) )
		{
			effect.Animathrow.effectSet(DB, nageru.getPAnimaThrowModel() );

			nageru.addCombo();
			nageru.removeAnimaThrow(DB);
			rocking.setDamage(nageru.getAnimaThrowDamage(), 0 );

			sound.playEnemyDamageSE(DB);
		}
		rocking.focusToPlayer(nageru.getPos());
		rocking.actAI(DB, nageru.getPos());
		rocking.translatePlayer(DB);
		rocking.updateRushBlock(DB);
		rocking.updateModel(DB);
		rocking.updateInv();

		rocking.updateShockwave(DB);
		rocking.moveLimit();


		
		camera.updateSingle( DB->modelDB.getModel( "nageru" )->getPosition() );
		//camera.updateVS( DB->modelDB.getModel( "nageru" )->getPosition(), DB->modelDB.getModel("rocking")->getPosition() );
		camera.addAngle( double(input->checkStick().rightX )/500 * (PI/180) );
		camera.addHeight( double(input->checkStick().rightY )/400.0  );
		if(cameraMode == 0 )
		{
			camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
		}
		else
		{
			if(input->checkPress( INPUT_6 ) )
			{
				camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
			}
		}


		interFace.setP1_LifeRate(nageru.getStatusBase().life, nageru.getStatusBase().lifeMax);
		interFace.setP1_Stock(nageru.getStatusBase().stock );
		interFace.setP1_Anima(nageru.getStatusBase().anima);
		interFace.setP1_Combo(nageru.getStatusBase().combo);
		interFace.setP2_LifeRate(rocking.getStatusBase().life, rocking.getStatusBase().lifeMax);
		interFace.setP2_Stock(rocking.getStatusBase().stock );
		interFace.setP2_Anima(rocking.getStatusBase().anima);
		interFace.setP2_Combo(rocking.getStatusBase().combo);
		interFace.setTime(int(timer.getTime() * 100 ) );
		interFace.updateGraph(DB);

		field.blockLost( nageru.calcThrowBlockDistance(), 1);
		field.update();

		effect.update(DB);

		if(nageru.getMotionStatus() == 12 || nageru.getMotionStatus() == 13 )
		{
			if(DB->systemDB.getAlphaPoint() <= 0.6 )
			{
				DB->systemDB.fade( 0.05 );
			}
			else
			{
				DB->graphDB.setPositionLT("gameOver", -130.0, 170.0);
				DB->graphDB.entryImage("gameOver");
				DB->graphDB.setPositionLT("continue", -300.0, 120.0);
				DB->graphDB.entryImage("continue");
				DB->graphDB.setPositionLT("yes", -75.0, -25.0);
				DB->graphDB.entryImage("yes");
				DB->graphDB.setPositionLT("no", -75.0, -125.0);
				DB->graphDB.entryImage("no");
				DB->graphDB.setPositionLT("cursor", -75, -25 -100.0*cursorNum );
				DB->graphDB.entryImage("cursor");

				if( input->checkDown( INPUT_UP ) )
				{
					cursorNum --;
					if(cursorNum <= 0 ) cursorNum = 0;
				}
				if( input->checkDown( INPUT_DOWN ) )
				{
					cursorNum ++;
					if(cursorNum >= 1 ) cursorNum = 1;
				}
				if( input->checkDown( INPUT_4 ) )
				{
					if(cursorNum == 0 )
					{
						DB->systemDB.fade( -100 );
						DB->graphDB.removeImage("gameOver");
						DB->graphDB.removeImage("continue");
						DB->graphDB.removeImage("yes");
						DB->graphDB.removeImage("no");
						DB->graphDB.removeImage("cursor");

						for(int i=0; i<6; i++ )
						{
							dammyID[i] = nageru.getLiftBlockID(i);
							nageru.doThrow(DB->systemDB.getScene());
							field.blockLost( dammyID[i], 1);
							field.blockRevival(1, dammyID);
						}
						field.deleteField();
						field.loadEditFieldData( 6 , &nageruPos , &enemyPos );

						nageru.init(DB);
						rocking.init();
						nageru.setPos(nageruPos );
						rocking.setPos(enemyPos);
				
						camera.setFocusToEnemy( nageru.getPos(), rocking.getPos() );
					}
					if(cursorNum == 1 )
					{
						DB->systemDB.fade( -100 );
						sound.stopMainBGM(DB);
						sound.stopRockingBGM(DB);
						sound.stopBontaBGM(DB);
						*scene = S_TITLE;
						return true;
					}
				}
			}
		}

		if(rocking.getMotionStatus() == 10 )
		{
			if(clearFlag == false )
			{
			for(int i=0; i<6; i++ )
			{
				dammyID[i] = nageru.getLiftBlockID(i);
				nageru.doThrow(DB->systemDB.getScene());
				field.blockLost( dammyID[i], 1);
				field.blockRevival(1, dammyID);
			}
			field.deleteField();
			field.loadEditFieldData( 6 , &nageruPos , &enemyPos );
				clearFlag = true;
			}
		}

		if(rocking.getMotionStatus() == 11 )
		{
			if(DB->systemDB.getAlphaPoint() <= 0.6 )
			{
				DB->systemDB.fade( 0.05 );
			}
			else
			{
				DB->graphDB.setPositionLT("stageClear", -145.0, 100.0);
				DB->graphDB.entryImage("stageClear");
				//DB->graphDB.setPositionLT("rank_in", -270.0, 10.0);
				//DB->graphDB.entryImage("rank_in");


				if( input->checkDown( INPUT_4 ) )
				{
					stageNum ++;
					DB->graphDB.entryImage("staffroll_1");
				}
			}
		}

		
		if(sound.getRockingBGMStatus() == true )
		{
			sound.playRockingBGM(DB);
		}

		//rocking.debug();
	}
	else if(stageNum == 3 )
	{
		if(endingStep == 0 )
		{
			if( input->checkDown( INPUT_4 ) )
			{
				endingStep ++;
				DB->graphDB.removeImage("staffroll_1" );
				DB->graphDB.entryImage("staffroll_2" );
			}
		}
		else if(endingStep == 1 )
		{
			if( input->checkDown( INPUT_4 ) )
			{
				endingStep ++;
				DB->graphDB.removeImage("staffroll_2" );
				DB->graphDB.entryImage("staffroll_3" );
			}

		}
		else if(endingStep == 2 )
		{
			if( input->checkDown( INPUT_4 ) )
			{
				sound.stopMainBGM(DB);
				sound.stopRockingBGM(DB);
				sound.stopBontaBGM(DB);
				endingStep = 0;
				*scene = S_TITLE;
				return true;
			}
		}
		
	}
	return false ;
}

/*
//wiǂݍ
*/
void CSingleMode::loadBG()
{
	if( !bgTex[0].readPNG( "dat/graph/maingame/bg/bg_under.png" ) )	fl_alert( "error read[bg_under.png]" );
	bgTex[0].setTextureSize( 4096.0 , 4096.0 );
	bgTex[0].setTexRendMode( FK_TEX_REND_NORMAL );
	bgTex[0].setTextureMode( FK_TEX_REPLACE );
	bgModel[0].setShape( &bgTex[0] );
	bgModel[0].glMoveTo( 0.0 , -1010.0 , 0.0 );
	bgModel[0].glFocus( 0.0 , -1025.0 , 0.0 );
	if( !bgTex[5].readPNG( "dat/graph/maingame/bg/bg_over.png" ) )	fl_alert( "error read[bg_over.png]" );
	bgTex[5].setTextureSize( 4096.0 , 4096.0 );
	bgTex[5].setTexRendMode( FK_TEX_REND_NORMAL );
	bgTex[5].setTextureMode( FK_TEX_REPLACE );
	bgModel[5].setShape( &bgTex[5] );
	bgModel[5].glMoveTo( 0.0 , 3060.0 , 0.0 );
	bgModel[5].glFocus( 0.0 , 3080.0 , 0.0 );
	for(int i=1 ; i<5 ; i++)
	{
		if( !bgTex[i].readPNG( "dat/graph/maingame/bg/bg_side.png" ) )
		{
			fl_alert( "error read[bg_side.png]" );
		}
		else
		{
			bgTex[i].setTextureSize( 4096.0 , 4096.0 );
			bgTex[i].setTexRendMode( FK_TEX_REND_SMOOTH );
			bgTex[i].setTextureMode( FK_TEX_REPLACE );
			bgModel[i].setShape( &bgTex[i] );
			if( i == 4 )
			{
				bgModel[1].glMoveTo( 2048.0 , 1024.0 , 0.0 );
				bgModel[2].glMoveTo( 0.0 , 1024.0 , 2048.0 );
				bgModel[3].glMoveTo( -2048.0 , 1024.0 , 0.0 );
				bgModel[4].glMoveTo( 0.0 , 1024.0 , -2048.0 );
				bgModel[1].glFocus( 2050.0 , 1024.0 , 0.0 );
				bgModel[2].glFocus( 0.0 , 1024.0 , 2050.0 );
				bgModel[3].glFocus( -2050.0 , 1024.0 , 0.0 );
				bgModel[4].glFocus( 0.0 , 1024.0 , -2050.0 );
			}
		}
	}

	for(int i =0; i<5; i++ )
	{
		DB->systemDB.getScene()->entryModel( &bgModel[i] );
	}
}